@@ -23,9 +23,9 @@ PKG_TYPES_MAP = {
     "npm": ["javascript", "node.js", "nodejs"],
     "nuget": [".net_framework", "csharp", ".net_core"],
     "pypi": ["python"],
-    "rubygems": ["ruby"],
+    "rubygems": ["ruby", "gem"],
     "golang": ["go"],
-    "crates": ["rust"],
+    "crates": ["rust", "crates.io", "cargo"],
 }
 
 # CPE Regex
