@@ -203,6 +203,8 @@ class GitHubSource(NvdSource):
             if isinstance(references, bytes):
                 references = references.decode("utf-8", "ignore")
             for p in cve["vulnerabilities"]["nodes"]:
+                if not p:
+                    continue
                 vendor = p["package"]["ecosystem"]
                 product = p["package"]["name"]
                 if ":" in product or "/" in product:
