@@ -203,8 +203,9 @@ class NpmSource(NvdSource):
                 severity
             )
             exploitabilityScore = score
-            if v.get("metadata") and v.get("metadata").get("exploitability"):
-                exploitabilityScore = v.get("metadata").get("exploitability")
+            metadata = v.get("metadata", {})
+            if isinstance(metadata, dict) and metadata.get("exploitability"):
+                exploitabilityScore = metadata.get("exploitability")
             cwe_id = v.get("cwe")
             version = v["vulnerable_versions"]
             fix_version = v.get("patched_versions")
